@@ -24,7 +24,7 @@
     (apply *builtin-plot2d* args)
     (let*
       ((nnn ($substring ($sha256sum ($sconcat "/plot2d" ($simplode args))) 1 7))
-       (pdf-file ($sconcat $plot_output_folder "/plot2d-" nnn ".pdf"))
+       (pdf-file ($sconcat (os-getcurrentdirectory) "plot2d-" nnn ".pdf"))
        (args-new (append args (list `((mlist) $pdf_file ,pdf-file)))))
       (apply *builtin-plot2d* args-new))))
 
@@ -37,7 +37,7 @@
     (apply *builtin-plot3d* args)
     (let*
       ((nnn ($substring ($sha256sum ($sconcat "plot3d" ($simplode args))) 1 7))
-       (pdf-file ($sconcat $plot_output_folder "/plot3d-" nnn ".pdf"))
+       (pdf-file ($sconcat (os-getcurrentdirectory) "plot3d-" nnn ".pdf"))
        (args-new (append args (list `((mlist) $pdf_file ,pdf-file)))))
       (apply *builtin-plot3d* args-new))))
 
@@ -60,7 +60,7 @@
     (apply *builtin-draw* args)
     (let*
       ((nnn ($substring ($sha256sum ($sconcat "draw" ($simplode args))) 1 7))
-       (file_name ($sconcat $plot_output_folder "/draw-" nnn))
+       (file_name ($sconcat (os-getcurrentdirectory) "draw-" nnn))
        (args-new (append args (list `((mequal) $file_name ,file_name))))
        (args-new (append args-new (list `((mequal) $terminal $pdf)))))
       (apply *builtin-draw* args-new)
@@ -77,7 +77,7 @@
     (apply *builtin-draw2d* args)
     (let*
       ((nnn ($substring ($sha256sum ($sconcat "draw2d" ($simplode args))) 1 7))
-       (file_name ($sconcat $plot_output_folder "/draw2d-" nnn))
+       (file_name ($sconcat (os-getcurrentdirectory) "draw2d-" nnn))
        (args-new (append args (list `((mequal) $file_name ,file_name))))
        (args-new (append args-new (list `((mequal) $terminal $pdfcairo)))))
       (apply *builtin-draw2d* args-new)
@@ -94,7 +94,7 @@
     (apply *builtin-draw3d* args)
     (let*
       ((nnn ($substring ($sha256sum ($sconcat "draw3d" ($simplode args))) 1 7))
-       (file_name ($sconcat $plot_output_folder "/draw3d-" nnn))
+       (file_name ($sconcat (os-getcurrentdirectory) "draw3d-" nnn))
        (args-new (append args (list `((mequal) $file_name ,file_name))))
        (args-new (append args-new (list `((mequal) $terminal $pdf)))))
       (apply *builtin-draw3d* args-new)
